@@ -22,10 +22,6 @@
 #' @param sphere if true, sphere all variables
 #' @param ... ignored
 #' @return an (invisible) list of bases visited during this tour
-#' @references Hadley Wickham, Dianne Cook, Heike Hofmann, Andreas Buja
-#'   (2011). tourr: An R Package for Exploring Multivariate Data with
-#'   Projections. Journal of Statistical Software, 40(2), 1-18.
-#'   \url{https://www.jstatsoft.org/v40/i02/}.
 #' @export
 #' @examples
 #' f <- flea[, 1:6]
@@ -40,7 +36,7 @@ animate <- function(data, tour_path = grand_tour(), display = display_xy(),
                     start = NULL, aps = 1, fps = 10, max_frames = Inf,
                     rescale = TRUE, sphere = FALSE, ...) {
   record <-
-    dplyr::tibble(
+    tibble::tibble(
       basis = list(),
       index_val = numeric(),
       info = character(),
