@@ -12,20 +12,19 @@
 #' @examples
 #' animate_pcp(flea[, 1:6], grand_tour(3))
 #' animate_pcp(flea[, 1:6], grand_tour(5))
-display_pcp <- function(...)
-{
+display_pcp <- function(...) {
   labels <- NULL
   limit <- NULL
   init <- function(data) {
-    labels <<- abbreviate(colnames(data),2)
-    limit <<- max(sqrt(rowSums(data ^ 2)))
+    labels <<- abbreviate(colnames(data), 2)
+    limit <<- max(sqrt(rowSums(data^2)))
   }
 
   render_frame <- function() {
     blank_plot(xlim = c(0, 1), ylim = c(-limit, limit))
   }
   render_transition <- function() {
-    rect(0, -limit, 1, limit, col="#FFFFFFE6", border=NA)
+    rect(0, -limit, 1, limit, col = "#FFFFFFE6", border = NA)
   }
   render_data <- function(data, proj, geodesic) {
     d <- ncol(proj)
@@ -34,8 +33,8 @@ display_pcp <- function(...)
     xs <- rep(c(xpos, NA), length = length(ys))
 
     # Grid lines
-    segments(xpos, limit, xpos, -limit, col="grey90")
-    segments(0, 0, 1, 0, col="grey90")
+    segments(xpos, limit, xpos, -limit, col = "grey90")
+    segments(0, 0, 1, 0, col = "grey90")
 
     # Projection values
     label_df <- data.frame(
@@ -45,9 +44,9 @@ display_pcp <- function(...)
     )
     with(
       subset(label_df, abs(y) > 0.05),
-      text(x, y, label = label, col="grey50", pos = 4)
+      text(x, y, label = label, col = "grey50", pos = 4)
     )
-    with(label_df, points(x, y, col="grey50", pch = 20))
+    with(label_df, points(x, y, col = "grey50", pch = 20))
 
     # Data values
     lines(xs, ys)
@@ -60,18 +59,13 @@ display_pcp <- function(...)
     render_data = render_data,
     render_target = nul
   )
-
 }
-
-globalVariables("y")
-
+# globalVariables("y")
 
 #' @rdname display_pcp
 #' @inheritParams animate
 #' @export
 animate_pcp <- function(data, tour_path = grand_tour(3), ...) {
-
-
   animate(
     data = data, tour_path = tour_path,
     display = display_pcp(...), ...
